Script 'mail_helper' called by obssrc
Hello community,

here is the log from the commit of package rocclr for openSUSE:Factory checked 
in at 2026-09-21 14:29:24
++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
Comparing /work/SRC/openSUSE:Factory/rocclr (Old)
 and      /work/SRC/openSUSE:Factory/.rocclr.new.383539 (New)
++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

Package is "rocclr"

Mon Sep 21 14:29:24 2026 rev:2 rq:1379138 version:7.2.2

Changes:
--------
--- /work/SRC/openSUSE:Factory/rocclr/rocclr.changes    2025-10-20 
13:35:30.019684168 +0200
+++ /work/SRC/openSUSE:Factory/.rocclr.new.383539/rocclr.changes        
2026-09-21 14:30:10.399024494 +0200
@@ -1,0 +2,74 @@
+Fri Sep 18 00:00:00 UTC 2026 - Jeremy Newton <[email protected]>
+
+- Add reproducible.patch to fix reproducible builds
+
+-------------------------------------------------------------------
+Thu Jul 16 00:00:00 UTC 2026 - Fedora Release Engineering 
<[email protected]>
+
+- Rebuilt for https://fedoraproject.org/wiki/Fedora_45_Mass_Rebuild
+
+-------------------------------------------------------------------
+Tue Jun  2 00:00:00 UTC 2026 - Tom Rix <[email protected]>
+
+- merge compat changes
+
+-------------------------------------------------------------------
+Tue Mar 24 00:00:00 UTC 2026 - Tom Rix <[email protected]>
+
+- Update to 7.2.1
+
+-------------------------------------------------------------------
+Thu Mar  5 00:00:00 UTC 2026 - Tom Rix <[email protected]>
+
+- Add --with preview
+
+-------------------------------------------------------------------
+Mon Feb 23 00:00:00 UTC 2026 - Tom Rix <[email protected]>
+
+- Cleanup specfile
+
+-------------------------------------------------------------------
+Mon Jan 26 00:00:00 UTC 2026 - Tom Rix <[email protected]>
+
+- Update to 7.2.0
+
+-------------------------------------------------------------------
+Sat Jan 17 00:00:00 UTC 2026 - Fedora Release Engineering 
<[email protected]>
+
+- Rebuilt for https://fedoraproject.org/wiki/Fedora_44_Mass_Rebuild
+
+-------------------------------------------------------------------
+Tue Dec 16 00:00:00 UTC 2025 - Tom Rix <[email protected]>
+
+- Add --with compat
+
+-------------------------------------------------------------------
+Wed Nov 26 00:00:00 UTC 2025 - Tom Rix <[email protected]>
+
+- Update to 7.1.1
+
+-------------------------------------------------------------------
+Wed Nov 19 00:00:00 UTC 2025 - Tom Rix <[email protected]>
+
+- Fix building on SUSE 15.6
+  Add: 0001-rocclr-replace-std-filesystem-exists-with-access.patch
+
+-------------------------------------------------------------------
+Thu Oct 30 00:00:00 UTC 2025 - Tom Rix <[email protected]>
+
+- Update to 7.1.0
+  Add: 0001-rocclr-long-variants-for-__ffsll.patch
+  Remove: 0001-add-long-variants-for-__ffsll.patch
+
+-------------------------------------------------------------------
+Sat Oct 25 00:00:00 UTC 2025 - Tom Rix <[email protected]>
+
+- Use SUSE cppheaderparser name
+
+-------------------------------------------------------------------
+Sun Oct 19 22:37:18 UTC 2025 - Marcus Rueckert <[email protected]>
+
+- enable generation of the profiling header in all cases
+  SUSE has the package just with a different name.
+
+-------------------------------------------------------------------
@@ -6,0 +81,10 @@
+Fri Oct 10 00:00:00 UTC 2025 - Tom Rix <[email protected]>
+
+- Update to 7.0.2
+
+-------------------------------------------------------------------
+Mon Sep 22 00:00:00 UTC 2025 - Tom Rix <[email protected]>
+
+- Update to 7.0.1
+
+-------------------------------------------------------------------
@@ -103,0 +188 @@
+  Add: 909fa3dcb644f7ca422ed1a980a54ac426d831b1.patch

Old:
----
  0001-add-long-variants-for-__ffsll.patch
  HIP-6.4.2.tar.gz
  rocclr-6.4.2.tar.gz

New:
----
  0001-rocclr-long-variants-for-__ffsll.patch
  0001-rocclr-replace-std-filesystem-exists-with-access.patch
  clr-7.2.2.tar.gz
  hip-7.2.2.tar.gz
  reproducible.patch

----------(Old B)----------
  Old:  Add: 0001-rocclr-long-variants-for-__ffsll.patch
  Remove: 0001-add-long-variants-for-__ffsll.patch
----------(Old E)----------

----------(New B)----------
  New:- Update to 7.1.0
  Add: 0001-rocclr-long-variants-for-__ffsll.patch
  Remove: 0001-add-long-variants-for-__ffsll.patch
  New:- Fix building on SUSE 15.6
  Add: 0001-rocclr-replace-std-filesystem-exists-with-access.patch
  New:
- Add reproducible.patch to fix reproducible builds
----------(New E)----------

++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

Other differences:
------------------
++++++ rocclr.spec ++++++
--- /var/tmp/diff_new_pack.vGwGUQ/_old  2026-09-21 14:30:11.355064513 +0200
+++ /var/tmp/diff_new_pack.vGwGUQ/_new  2026-09-21 14:30:11.357064597 +0200
@@ -1,6 +1,19 @@
 #
 # spec file for package rocclr
 #
+# Copyright (c) 2026 SUSE LLC and contributors
+#
+# All modifications and additions to the file contributed by third parties
+# remain the property of their copyright owners, unless otherwise agreed
+# upon. The license for this file, and modifications and additions to the
+# file, is the same license as for the pristine package itself (unless the
+# license for the pristine package is not an Open Source License, in which
+# case the license is the MIT License). An "Open Source License" is a
+# license that conforms to the Open Source Definition (Version 1.9)
+# published by the Open Source Initiative.
+
+# Please submit bugfixes or comments via https://bugs.opensuse.org/
+#
 # Copyright Fedora Project Authors.
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -22,33 +35,46 @@
 # THE SOFTWARE.
 #
 
-# ROCclr loads comgr at run time by soversion, so this needs to be checked when
-# updating this package as it's used for the comgr requires for opencl and hip:
-# Copyright (c) 2025 SUSE LLC and contributors
-#
-# All modifications and additions to the file contributed by third parties
-# remain the property of their copyright owners, unless otherwise agreed
-# upon. The license for this file, and modifications and additions to the
-# file, is the same license as for the pristine package itself (unless the
-# license for the pristine package is not an Open Source License, in which
-# case the license is the MIT License). An "Open Source License" is a
-# license that conforms to the Open Source Definition (Version 1.9)
-# published by the Open Source Initiative.
 
-# Please submit bugfixes or comments via https://bugs.opensuse.org/
-#
+%global upstreamname clr
+
+%bcond_with preview
+%if %{with preview}
+%global rocm_major 7
+%global rocm_minor 14
+%global rocm_patch 0
+%global rocm_release %{rocm_major}.%{rocm_minor}
+%global pkg_src therock-%{rocm_release}
+%else
+%global rocm_major 7
+%global rocm_minor 2
+%global rocm_patch 2
+%global rocm_release %{rocm_major}.%{rocm_minor}
+%global pkg_src rocm-%{rocm_release}.%{rocm_patch}
+%endif
 
+%global rocm_version %{rocm_release}.%{rocm_patch}
 
+%bcond_with compat
+%if %{with compat}
+%global pkg_libdir lib
+%global pkg_prefix %{_prefix}/lib64/rocm/rocm-%{rocm_release}
+%global pkg_suffix %{rocm_release}
+%global skip_install_rpath OFF
+%else
+%global pkg_libdir %{_lib}
+%global pkg_prefix %{_prefix}
+%global pkg_suffix %{nil}
+%global skip_install_rpath ON
+%endif
+%global pkg_name rocclr%{pkg_suffix}
+
+# ROCclr loads comgr at run time by soversion, so this needs to be checked when
+# updating this package as it's used for the comgr requires for opencl and hip:
 %global comgr_maj_api_ver 3
 # See the file "rocclr/device/comgrctx.cpp" for reference:
 # 
https://github.com/ROCm-Developer-Tools/ROCclr/blob/develop/device/comgrctx.cpp#L62
 
-%global rocm_major 6
-%global rocm_minor 4
-%global rocm_patch 2
-%global rocm_release %{rocm_major}.%{rocm_minor}
-%global rocm_version %{rocm_release}.%{rocm_patch}
-
 %global toolchain clang
 
 %bcond_with debug
@@ -58,10 +84,11 @@
 %global build_type RelWithDebInfo
 %endif
 
-%if 0%{?fedora}
-%bcond_without cppheaderparser
-%else
+%if 0%{?suse_version} <= 1600
+# python3-CppHeaderParser not available on 15.6
 %bcond_with cppheaderparser
+%else
+%bcond_without cppheaderparser
 %endif
 %if %{with cppheaderparser}
 %global build_prof_api ON
@@ -85,8 +112,12 @@
 %endif
 %endif
 %if 0%{?fedora}
+%if %{with compat}
+%bcond_with ocl
+%else
 %bcond_without ocl
 %endif
+%endif
 
 %if %{with ocl}
 %global build_ocl ON
@@ -96,32 +127,49 @@
 
 %bcond_with docs
 
-Name:           rocclr
+Name:           %{pkg_name}
 Version:        %{rocm_version}
-Release:        4%{?dist}
+%if %{with preview}
+Release:        1%{?dist}
+%else
+Release:        3%{?dist}
+%endif
 Summary:        ROCm Compute Language Runtime
-URL:            https://github.com/ROCm/clr
-License:        MIT
-Source0:        
%{url}/archive/refs/tags/rocm-%{version}.tar.gz#/%{name}-%{version}.tar.gz
+License:        Apache-2.0 AND MIT AND MIT-Khronos-old
+# The main license is MIT
+# OpenCL parts are licensed with Khronos AND Apache-2.0
+URL:            https://github.com/ROCm/rocm-systems
+Source0:        
%{url}/releases/download/%{pkg_src}/%{upstreamname}.tar.gz#/%{upstreamname}-%{version}.tar.gz
 # TODO: it would be nice to separate this into its own package:
-Source1:        
https://github.com/ROCm-Developer-Tools/HIP/archive/refs/tags/rocm-%{version}.tar.gz#/HIP-%{version}.tar.gz
+Source1:        
%{url}/releases/download/%{pkg_src}/hip.tar.gz#/hip-%{version}.tar.gz
 
 # a fix for building blender
-Patch8:         0001-add-long-variants-for-__ffsll.patch
+Patch1:         0001-rocclr-long-variants-for-__ffsll.patch
 
 #https://github.com/ROCm/clr/pull/97
-Patch10:        909fa3dcb644f7ca422ed1a980a54ac426d831b1.patch
+Patch2:         909fa3dcb644f7ca422ed1a980a54ac426d831b1.patch
+
+%if %{without preview}
+# std::filesystem is c++17 and that is too new for suse 15
+# https://github.com/ROCm/rocm-systems/issues/1947
+Patch3:         0001-rocclr-replace-std-filesystem-exists-with-access.patch
+%endif
+
+# Fix for reproducible builds
+Patch4:         reproducible.patch
 
 BuildRequires:  cmake
 %if %{with docs}
 BuildRequires:  doxygen
 %endif
-%if 0%{?fedora}
+%if 0%{?fedora} || 0%{?suse_version}
 BuildRequires:  fdupes
+%endif
+%if 0%{?fedora}
 BuildRequires:  perl-generators
 %endif
 BuildRequires:  gcc-c++
-BuildRequires:  hipcc
+BuildRequires:  hipcc%{pkg_suffix}
 BuildRequires:  libffi-devel
 BuildRequires:  libzstd-devel
 BuildRequires:  perl
@@ -154,13 +202,18 @@
 %endif
 BuildRequires:  pkgconfig(numa)
 %if %{with cppheaderparser}
+%if 0%{?suse_version}
+BuildRequires:  %{python_module CppHeaderParser}
+%else
 BuildRequires:  python3-cppheaderparser
 %endif
-BuildRequires:  rocm-comgr-devel
-BuildRequires:  rocm-compilersupport-macros
-BuildRequires:  rocm-runtime-devel >= %{rocm_release}
-# TODO: drop this when we bump to 7.0, 6.4.2 added some API's that rocclr needs
-BuildRequires:  rocm-runtime-devel >= 6.4.2
+%endif
+BuildRequires:  rocm-comgr%{pkg_suffix}-devel
+BuildRequires:  rocm-compilersupport%{pkg_suffix}-macros
+BuildRequires:  rocm-runtime%{pkg_suffix}-devel >= %{rocm_release}
+%if %{with preview}
+BuildRequires:  simde-devel
+%endif
 BuildRequires:  zlib-devel
 
 # ROCclr relies on some x86 intrinsics
@@ -178,7 +231,7 @@
 ROCm Compute Language Runtime
 
 %if %{with ocl}
-%package -n rocm-opencl
+%package -n rocm-opencl%{pkg_suffix}
 Summary:        ROCm OpenCL platform and device tool
 Requires:       comgr(major) = %{comgr_maj_api_ver}
 %if 0%{?fedora}
@@ -192,69 +245,78 @@
 %if 0%{?suse_version}
 Recommends:     LibOpenCL1
 %endif
+Requires:       rocm-filesystem%{pkg_suffix}
+Requires:       rocm-runtime%{pkg_suffix}
 
-%description -n rocm-opencl
+%description -n rocm-opencl%{pkg_suffix}
 ROCm OpenCL language runtime.
 Supports offline and in-process/in-memory compilation.
 
-%package -n rocm-opencl-devel
+%package -n rocm-opencl%{pkg_suffix}-devel
 Summary:        ROCm OpenCL development package
-Requires:       rocm-opencl%{?_isa} = %{version}-%{release}
+Requires:       rocm-opencl%{pkg_suffix}%{?_isa} = %{version}-%{release}
 %if 0%{?fedora}
 Requires:       OpenCL-ICD-Loader-devel%{?_isa}
 %else
 Requires:       ocl-icd-devel%{?_isa}
 %endif
 
-%description -n rocm-opencl-devel
+%if 0%{?suse_version}
+%ldconfig_scriptlets -n rocm-opencl%{pkg_suffix}
+%endif
+
+%description -n rocm-opencl%{pkg_suffix}-devel
 The AMD ROCm OpenCL development package.
 
-%package -n rocm-clinfo
+%package -n rocm-clinfo%{pkg_suffix}
 Summary:        ROCm OpenCL platform and device tool
+Requires:       rocm-filesystem%{pkg_suffix}
 
-%description -n rocm-clinfo
+%description -n rocm-clinfo%{pkg_suffix}
 A simple ROCm OpenCL application that enumerates all possible platform and
 device information.
 %endif
 
-%package -n rocm-hip
+%package -n rocm-hip%{pkg_suffix}
 Summary:        ROCm HIP platform and device tool
-Requires:       hipcc
-Requires:       comgr(major) = %{comgr_maj_api_ver}
+Requires:       hipcc%{pkg_suffix}
+Requires:       rocm-filesystem%{pkg_suffix}
+Requires:       rocm-runtime%{pkg_suffix}
+Requires:       comgr%{pkg_suffix}(major) = %{comgr_maj_api_ver}
 
-%description -n rocm-hip
+%description -n rocm-hip%{pkg_suffix}
 HIP is a C++ Runtime API and Kernel Language that allows developers to create
 portable applications for AMD and NVIDIA GPUs from the same source code.
 
-%post -n rocm-hip -p /sbin/ldconfig
-%postun -n rocm-hip -p /sbin/ldconfig
+%if 0%{?suse_version}
+%ldconfig_scriptlets -n rocm-hip%{pkg_suffix}
+%endif
 
-%package -n rocm-hip-devel
+%package -n rocm-hip%{pkg_suffix}-devel
 Summary:        ROCm HIP development package
-Requires:       rocm-comgr-devel
-Requires:       rocm-hip%{?_isa} = %{version}-%{release}
-Requires:       rocm-runtime-devel >= %{rocm_release}
+Requires:       rocm-comgr%{pkg_suffix}-devel
+Requires:       rocm-hip%{pkg_suffix}%{?_isa} = %{version}-%{release}
+Requires:       rocm-runtime%{pkg_suffix}-devel >= %{rocm_release}
 # For roc-obj-ls
 Requires:       binutils
 Requires:       gawk
 
-Provides:       hip-devel = %{version}-%{release}
-Obsoletes:      hip-devel < 6.0.0
+Provides:       hip%{pkg_suffix}-devel = %{version}-%{release}
 
-%description -n rocm-hip-devel
+%description -n rocm-hip%{pkg_suffix}-devel
 ROCm HIP development package.
 
 %if %{with docs}
-%package -n hip-doc
+%package -n hip%{pkg_suffix}-doc
 Summary:        HIP API documentation package
 BuildArch:      noarch
 
-%description -n hip-doc
+%description -n hip%{pkg_suffix}-doc
 This package contains documentation for the hip package
 %endif
 
 %prep
-%autosetup -N -a 1 -n clr-rocm-%{version}
+%autosetup -N -a 1 -n %{upstreamname}
 
 # ROCclr patches
 %autopatch -p1
@@ -289,7 +351,7 @@
 %if %{with docs}
 # Disable doxygen timestamps:
 sed -i 's/^\(HTML_TIMESTAMP.*\)YES/\1NO/' \
-    HIP-rocm-%{version}/docs/doxygen-input/doxy.cfg
+    hip/docs/doxygen-input/doxy.cfg
 %endif
 
 # Use cpack is not needed when we are doing the packaging here
@@ -309,24 +371,27 @@
 export PATH=%{rocmllvm_bindir}:$PATH
 
 %cmake \
-    -DCMAKE_CXX_COMPILER=%rocmllvm_bindir/clang++ \
-    -DCMAKE_C_COMPILER=%rocmllvm_bindir/clang \
+    -DCMAKE_CXX_COMPILER=%rocmllvm_bindir/amdclang++ \
+    -DCMAKE_C_COMPILER=%rocmllvm_bindir/amdclang \
     -DCMAKE_AR=%rocmllvm_bindir/llvm-ar \
     -DCMAKE_RANLIB=%rocmllvm_bindir/llvm-ranlib \
     -DCMAKE_LINKER=%rocmllvm_bindir/ld.lld \
-    -DHIP_COMMON_DIR=$p/hip-rocm-%{version} \
-    -DCMAKE_INSTALL_LIBDIR=%{_lib} \
-    -DHIPCC_BIN_DIR=%{_bindir} \
-    -DHIP_COMPILER=%rocmllvm_bindir/clang++ \
+    -DCMAKE_INSTALL_LIBDIR=%{pkg_libdir} \
+    -DCMAKE_INSTALL_PREFIX=%{pkg_prefix} \
+    -DCMAKE_INSTALL_RPATH=%{pkg_prefix}/%{pkg_libdir} \
+    -DCMAKE_PREFIX_PATH=%{rocmllvm_cmakedir}/.. \
+    -DCMAKE_SKIP_INSTALL_RPATH=%{skip_install_rpath} \
+    -DHIPCC_BIN_DIR=%{pkg_prefix}/bin \
+    -DHIP_COMMON_DIR=$p/hip \
+    -DHIP_COMPILER=%rocmllvm_bindir/amdclang++ \
     -DHIP_PLATFORM=amd \
-    -DROCM_PATH=%{_prefix} \
+    -DROCM_PATH=%{pkg_prefix} \
     -DBUILD_ICD=OFF \
     -DCLR_BUILD_HIP=ON \
     -DCLR_BUILD_OCL=%{build_ocl} \
     -DFILE_REORG_BACKWARD_COMPATIBILITY=OFF \
     -DHIP_ENABLE_ROCPROFILER_REGISTER=OFF \
     -DUSE_PROF_API=%{build_prof_api} \
-    -DCMAKE_PREFIX_PATH=%{rocmllvm_cmakedir}/.. \
     -DCMAKE_BUILD_TYPE=%{build_type}
 
 %cmake_build
@@ -335,81 +400,107 @@
 %cmake_install
 
 %if %{with ocl}
+%if %{without compat}
 # Install OpenCL ICD configuration:
 install -D -m 644 opencl/config/amdocl64.icd \
     %{buildroot}%{_sysconfdir}/OpenCL/vendors/amdocl64.icd
+%endif
 
 # Avoid file conflicts with opencl-headers package:
-mkdir -p %{buildroot}%{_includedir}/%{name}
-mv %{buildroot}%{_includedir}/CL %{buildroot}%{_includedir}/%{name}/CL
+mkdir -p %{buildroot}%{pkg_prefix}/include/%{name}
+mv %{buildroot}%{pkg_prefix}/include/CL 
%{buildroot}%{pkg_prefix}/include/%{name}/CL
 
 # Avoid file conflicts with clinfo package:
-mv %{buildroot}%{_bindir}/clinfo %{buildroot}%{_bindir}/rocm-clinfo
+mv %{buildroot}%{pkg_prefix}/bin/clinfo 
%{buildroot}%{pkg_prefix}/bin/rocm-clinfo
 %endif
 
 # Clean up file dupes
-%if 0%{?fedora}
-%fdupes %{buildroot}/%{_docdir}/hip
+%if 0%{?fedora} || 0%{?suse_version}
+%fdupes %{buildroot}/
 %endif
 
 # TODO send upstream a patch, libhip should be installed with cmake's 'TARGETS'
-chmod 755 %{buildroot}%{_libdir}/lib*.so*
+chmod 755 %{buildroot}%{pkg_prefix}/%{pkg_libdir}/lib*.so*
 
 # Unnecessary file and is not FHS compliant:
-rm %{buildroot}%{_libdir}/.hipInfo
+rm %{buildroot}%{pkg_prefix}/%{pkg_libdir}/.hipInfo
 
+%if %{without preview}
 # Windows files:
-rm %{buildroot}%{_bindir}/*.bat
+rm %{buildroot}%{pkg_prefix}/bin/*.bat
+%endif
+
+%if %{with preview}
+# 7.13+ needs some help installing scripts
+mkdir -p %{buildroot}%{pkg_prefix}/bin
+install -m 755 hip/bin/hipcc_cmake_linker_helper %{buildroot}%{pkg_prefix}/bin/
+install -m 755 hip/bin/hipdemangleatp            %{buildroot}%{pkg_prefix}/bin/
+%endif
 
-rm -f %{buildroot}%{_prefix}/share/doc/packages/rocclr*/LICENSE.txt
-rm -f %{buildroot}%{_prefix}/share/doc/opencl*/LICENSE.txt
-rm -f %{buildroot}%{_prefix}/share/doc/hip-asan/LICENSE.txt
-rm -f %{buildroot}%{_prefix}/share/doc/hip/LICENSE.txt
+rm -f %{buildroot}%{pkg_prefix}/share/doc/packages/rocclr*/LICENSE.md
+rm -f %{buildroot}%{pkg_prefix}/share/doc/opencl*/LICENSE.md
+rm -f %{buildroot}%{pkg_prefix}/share/doc/hip-asan/LICENSE.md
+rm -f %{buildroot}%{pkg_prefix}/share/doc/hip/LICENSE.md
 
 %if %{with ocl}
-%files -n rocm-opencl
+%files -n rocm-opencl%{pkg_suffix}
 %if 0%{?suse_version}
 %dir %{_sysconfdir}/OpenCL/
 %dir %{_sysconfdir}/OpenCL/vendors
 %endif
-%license opencl/LICENSE.txt
+%if %{without compat}
+%license opencl/LICENSE.md
 %config(noreplace) %{_sysconfdir}/OpenCL/vendors/amdocl64.icd
-%{_libdir}/libamdocl64.so.%{rocm_major}{,.*}
-%{_libdir}/libcltrace.so.%{rocm_major}{,.*}
+%endif
+%if %{with preview}
+%{pkg_prefix}/%{pkg_libdir}/opencl/libamdocl64.so.%{rocm_major}{,.*}
+%else
+%{pkg_prefix}/%{pkg_libdir}/libamdocl64.so.%{rocm_major}{,.*}
+%endif
+%{pkg_prefix}/%{pkg_libdir}/libcltrace.so.%{rocm_major}{,.*}
 
-%files -n rocm-opencl-devel
-%{_libdir}/libamdocl64.so
-%{_libdir}/libcltrace.so
-%{_includedir}/%{name}
-
-%files -n rocm-clinfo
-%license opencl/LICENSE.txt
-%{_bindir}/rocm-clinfo
-%endif
-
-%files -n rocm-hip
-%license hipamd/LICENSE.txt
-%{_libdir}/libamdhip64.so.%{rocm_major}{,.*}
-%{_libdir}/libhiprtc.so.%{rocm_major}{,.*}
-%{_libdir}/libhiprtc-builtins.so.%{rocm_major}{,.*}
-%{_datadir}/hip
-
-%files -n rocm-hip-devel
-%{_bindir}/roc-*
-%{_libdir}/libamdhip64.so
-%{_libdir}/libhiprtc.so
-%{_libdir}/libhiprtc-builtins.so
-%{_libdir}/cmake/hip*
-%{_bindir}/hipdemangleatp
-%{_bindir}/hipcc_cmake_linker_helper
-%{_includedir}/hip
+%files -n rocm-opencl%{pkg_suffix}-devel
+%if %{with preview}
+%{pkg_prefix}/%{pkg_libdir}/opencl/libamdocl64.so
+%else
+%{pkg_prefix}/%{pkg_libdir}/libamdocl64.so
+%endif
+%{pkg_prefix}/%{pkg_libdir}/libcltrace.so
+%{pkg_prefix}/include/%{name}
+
+%files -n rocm-clinfo%{pkg_suffix}
+%license opencl/LICENSE.md
+%{pkg_prefix}/bin/rocm-clinfo
+%endif
+
+%files -n rocm-hip%{pkg_suffix}
+%license hipamd/LICENSE.md
+%{pkg_prefix}/%{pkg_libdir}/libamdhip64.so.%{rocm_major}{,.*}
+%{pkg_prefix}/%{pkg_libdir}/libhiprtc.so.%{rocm_major}{,.*}
+%{pkg_prefix}/%{pkg_libdir}/libhiprtc-builtins.so.%{rocm_major}{,.*}
+%{pkg_prefix}/share/hip
+%if %{with preview}
+%{pkg_prefix}/bin/hrr-playback
+%endif
+
+%files -n rocm-hip%{pkg_suffix}-devel
+%{pkg_prefix}/%{pkg_libdir}/libamdhip64.so
+%{pkg_prefix}/%{pkg_libdir}/libhiprtc.so
+%{pkg_prefix}/%{pkg_libdir}/libhiprtc-builtins.so
+%{pkg_prefix}/%{pkg_libdir}/cmake/hip*
+%{pkg_prefix}/include/hip
 %if %{with cppheaderparser}
-%{_includedir}/hip_prof_str.h
+%{pkg_prefix}/include/hip_prof_str.h
+%endif
+%if %{without preview}
+%{pkg_prefix}/bin/roc-*
 %endif
+%{pkg_prefix}/bin/hipcc_cmake_linker_helper
+%{pkg_prefix}/bin/hipdemangleatp
 
 %if %{with docs}
-%files -n hip-doc
-%license HIP-rocm-%{version}/LICENSE.txt
-%{_docdir}/hip
+%files -n hip%{pkg_suffix}-doc
+%license hip/LICENSE.md
+%{pkg_prefix}/share/doc/hip
 %endif
 

++++++ 0001-rocclr-long-variants-for-__ffsll.patch ++++++
>From 43d7164df0ec0e9d0c52870db07efb367ae9ce82 Mon Sep 17 00:00:00 2001
From: Tom Rix <[email protected]>
Date: Thu, 30 Oct 2025 11:32:12 -0700
Subject: [PATCH] rocclr long variants for __ffsll

---
 hipamd/include/hip/amd_detail/amd_device_functions.h | 8 ++++++++
 1 file changed, 8 insertions(+)

diff --git a/hipamd/include/hip/amd_detail/amd_device_functions.h 
b/hipamd/include/hip/amd_detail/amd_device_functions.h
index cf331225707b..26bb04ca630d 100644
--- a/hipamd/include/hip/amd_detail/amd_device_functions.h
+++ b/hipamd/include/hip/amd_detail/amd_device_functions.h
@@ -68,6 +68,10 @@ __device__ static inline int __ffsll(unsigned long long int 
input) {
   return (input == 0 ? -1 : __builtin_ctzll(input)) + 1;
 }
 
+__device__ static inline unsigned int __ffsll(unsigned long int input) {
+    return ( input == 0 ? -1 : __builtin_ctzll(input) ) + 1;
+}
+
 __device__ static inline int __ffs(int input) {
   return (input == 0 ? -1 : __builtin_ctz(input)) + 1;
 }
@@ -76,6 +80,10 @@ __device__ static inline int __ffsll(long long int input) {
   return (input == 0 ? -1 : __builtin_ctzll(input)) + 1;
 }
 
+__device__ static inline unsigned int __ffsll(long int input) {
+    return ( input == 0 ? -1 : __builtin_ctzll(input) ) + 1;
+}
+
 // Given a 32/64-bit value exec mask and an integer value base (between 0 and 
WAVEFRONT_SIZE),
 // find the n-th (given by offset) set bit in the exec mask from the base bit, 
and return the bit
 // position. If not found, return -1.
-- 
2.51.0


++++++ 0001-rocclr-replace-std-filesystem-exists-with-access.patch ++++++
>From e1bad556ca529cfd92897e0a5b79c042b2de80fc Mon Sep 17 00:00:00 2001
From: Tom Rix <[email protected]>
Date: Wed, 19 Nov 2025 09:59:59 -0800
Subject: [PATCH] rocclr replace std::filesystem::exists with access

---
 hipamd/src/hip_library.cpp | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/hipamd/src/hip_library.cpp b/hipamd/src/hip_library.cpp
index 42b3c203e765..1460660687f3 100644
--- a/hipamd/src/hip_library.cpp
+++ b/hipamd/src/hip_library.cpp
@@ -20,10 +20,10 @@ OUT OF OR INN CONNECTION WITH THE SOFTWARE OR THE USE OR 
OTHER DEALINGS IN
 THE SOFTWARE.
 */
 
-#include <filesystem>
 #include <mutex>
 #include <string>
 #include <vector>
+#include <unistd.h>
 
 #include "hip/hip_runtime.h"
 #include "hip_library.hpp"
@@ -132,7 +132,7 @@ hipError_t hipLibraryLoadFromFile(hipLibrary_t* library, 
const char* fname,
                                   void** libraryOptionValues, unsigned int 
numLibraryOptions) {
   HIP_INIT_API(hipLibraryLoadFromFile, library, fname, jitOptions, 
jitOptionsValues, numJitOptions,
                libraryOptions, libraryOptionValues, numLibraryOptions);
-  if (library == nullptr || !std::filesystem::exists(fname) || numJitOptions > 
0) {
+  if (library == nullptr || access(fname, F_OK) || numJitOptions > 0) {
     HIP_RETURN(hipErrorInvalidValue);
   }
   auto* l = new hip::LibraryContainer(std::string(fname));
-- 
2.51.1


++++++ _scmsync.obsinfo ++++++
--- /var/tmp/diff_new_pack.vGwGUQ/_old  2026-09-21 14:30:11.433067778 +0200
+++ /var/tmp/diff_new_pack.vGwGUQ/_new  2026-09-21 14:30:11.436067903 +0200
@@ -1,6 +1,6 @@
-mtime: 1760389774
-commit: 0bca25c52b99712d5ab573017e42811898de55409bfc25d379f7de0b0305e358
-url: https://src.opensuse.org/ROCm/rocclr.git
-revision: 0bca25c52b99712d5ab573017e42811898de55409bfc25d379f7de0b0305e358
+mtime: 1789773063
+commit: 93cd6e578d0051aef458b64f94b7fe13ae22720b7d72e143f094bb59ae10d091
+url: https://src.opensuse.org/ROCm/rocclr
+revision: 93cd6e578d0051aef458b64f94b7fe13ae22720b7d72e143f094bb59ae10d091
 projectscmsync: https://src.opensuse.org/ROCm/_ObsPrj
 

++++++ build.specials.obscpio ++++++

++++++ build.specials.obscpio ++++++
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/.gitignore new/.gitignore
--- old/.gitignore      1970-01-01 01:00:00.000000000 +0100
+++ new/.gitignore      2026-09-19 01:11:03.000000000 +0200
@@ -0,0 +1,7 @@
+sources
+README.md
+_buildconfig*
+_buildinfo*
+debian
+.osc
+changelog

++++++ rocclr-6.4.2.tar.gz -> clr-7.2.2.tar.gz ++++++
++++ 351405 lines of diff (skipped)

++++++ reproducible.patch ++++++
Avoid adding randomness into hip_pch.o

via
/usr/lib64/rocm/llvm/lib/cmake/llvm/../../../bin/llvm-mc -o hip_pch.o 
/tmp/hip_pch.$PID/hip_pch.mcin --filetype=obj

diff --git a/hipamd/src/hip_embed_pch.sh b/hipamd/src/hip_embed_pch.sh
index 6c92d43..0a15078 100755
--- a/hipamd/src/hip_embed_pch.sh
+++ b/hipamd/src/hip_embed_pch.sh
@@ -100,7 +100,7 @@ EOF
 }
 
 generate_pch() {
-  tmp=$tmpdir/hip_pch.$$
+  tmp=$tmpdir/hip_pch.x
   mkdir -p $tmp
 
   create_hip_macro_file $tmp/hip_macros.h

Reply via email to